# This is the project for UDACITY's AWS MAchine learning challenge

This is a library to process binomial and gaussian distributions

More updates soon

## To install

pip install statpackagead

## Refer to the docs for more functions to use